@@ -26,7 +26,8 @@
 #include <QDebug>
 #include <QPainter>
 
-#include <kiconloader.h>
+#include <KIconLoader>
+#include <formatter/Formatter.h>  // from libksysguard
 
 #include "StyleEngine.h"
 
@@ -130,8 +131,8 @@ void BarGraph::paintEvent( QPaintEvent* )
       barHeight = h - 2;
 
     for ( uint b = 0; b < bars; b++ ) {
-      int topVal = (int) ( (float)barHeight / maxValue *
-                           ( samples[ b ] - minValue ) );
+      int topVal = int( (maxValue == 0.0) ? 0.0 :
+                   ( (float)barHeight / maxValue * ( samples[ b ] - minValue ) ) );
       /* TODO: This widget does not handle negative values properly. */
       if ( topVal < 0 )
         topVal = 0;
@@ -160,7 +161,7 @@ void BarGraph::paintEvent( QPaintEvent* )
                     footers[ b ] );
         p.drawText( b * barWidth + 3, h - fm.lineSpacing() - 2,
                     barWidth - 2 * 3, fm.lineSpacing(), Qt::AlignCenter,
-                    QStringLiteral( "%1" ).arg( samples[ b ] ) );
+                    KSysGuard::Formatter::formatValue( samples[b], KSysGuard::UnitNone ) );
       }
     }
   }
